@@ -29,13 +29,13 @@ def list_projects():
 def introduce():
     """ Welcomes a new user to the {name} tutorial."""
     config = api.get_local_config()
-    l(config['introduction' + '\n'], 'green')
+    l(config['introduction'] + '\n', 'green')
 
 
 def show_task():
     """ Informs the user of their current task."""
     task = api.get_task()
-    l(task['instruction' + '\n'], 'cyan')
+    l(task['instruction'] + '\n', 'cyan')
 
 
 
@@ -106,7 +106,6 @@ def progress():
         for j in full_local_config['lessons']:
             text = colored(j['name'], 'blue')
             print('  [ ] ' + text)
-            
             for i in range(len(j['tasks'])):
                 text = colored(i, 'green')
                 print('\t[ ] task ' + text)
@@ -162,12 +161,12 @@ def main():
 if __name__ == '__main__':
 
     help_message = (
-        'Available commands:\n\n' 
-        '\tlist     ----  Gives a list of all available tutorials.\n'  
-        '\tstart    ----  Starts a lesson.\n'  
-        '\tprogress ----  Displays your lesson progress in a tutorial\n' 
-        '\thint     ----  Gives a hint for the current problem\n'  
-        '\tresume   ----  Resumes the tutorial after user exits\n'  
+        'Available commands:\n\n'
+        '\tlist     ----  Gives a list of all available tutorials.\n'
+        '\tstart    ----  Starts a lesson.\n'
+        '\tprogress ----  Displays your lesson progress in a tutorial\n'
+        '\thint     ----  Gives a hint for the current problem\n'
+        '\tresume   ----  Resumes the tutorial after user exits\n'
         '\tnext     ----  Advances to the next lesson\n'
     )
     if (len(sys.argv) == 1):
